Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Response ¶
type Response struct {
// contains filtered or unexported fields
}
Response represents the response from an HTTP request.
func PostForm ¶
PostForm issues a POST to the specified URL, with data's keys and values URL-encoded as the request body.
func PostJson ¶
PostJson issues a POST to the specified URL, with data json encoding as the request body.
func (*Response) JsonUnmarshal ¶
JsonUnmarshal parses the JSON-encoded data and stores the result in the value pointed to by v.
func (*Response) XmlUnmarshal ¶
XmlUnmarshal parses the XML-encoded data and stores the result in the value pointed to by v.
Click to show internal directories.
Click to hide internal directories.